RotU
====

History
-------

This project began as an entry to a [Python Game Jam](https://itch.io/jam/python-game-jam-8).

In the spirit of that Jam, the theme for the work is *The Unknown*. I began to have ideas for a story,
and quickly realised I would need a [Dialogue Tree](https://en.wikipedia.org/wiki/Dialogue_tree).

So I parked the story ideas and went back to work on [Balladeer](https://tundish.github.io/balladeer/) to
add the functionality I needed. The good news is that Balladeer now supports
[Interactions](https://balladeer.readthedocs.io/en/latest/interaction.html)!

I ran out of time to submit my Jam entry. Nevertheless it was a worthwhile exercise, and I promised
myself that I wouldn't let all my hard work go to waste.

Today
-----

This repository is updated frequently. I'm maintaining a regular
[Development Blog](https://tundish.github.io/repo_of_the_unknown) to document the journey.
